@@ -1661,8 +1661,11 @@ src_process_config_changed (SREvent *event,
     	case CFGM_MAGNIFIER:
 	    src_process_config_changed_for_magnifier (config); 
 	    break;
+	case CFGM_SPEECH_VOICE_PARAM:
+	    src_speech_proces_voice_config_changed (config);
+	    break;
 	case CFGM_SPEECH:
-	case CFGM_SPEECH_VOICES:
+	case CFGM_SPEECH_VOICE:
 	    src_process_config_changed_for_speech (config);
 	    break;
 	case CFGM_SRCORE:
@@ -1674,8 +1677,6 @@ src_process_config_changed (SREvent *event,
 	case CFGM_PRESENTATION:
 	    src_process_config_changed_for_presentation (config);
 	    break;
-	case CFGM_SRLOW:
-	    break;
     }
 }
 
